import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { useState, useRef, useEffect, useImperativeHandle, forwardRef } from 'react';
import cn from 'classnames';
import CloseCircleFilled from '@ant-design/icons/CloseCircleFilled';
import { isDef } from '../_util/index';
import useUpdateEffect from '../_hook/useUpdateEffect/index';
import { defaultPrefixCls } from '../_config/dict';
;

function InputItem(props, ref) {
  var defaultValue = props.defaultValue,
      onChange = props.onChange,
      _props$maxLength = props.maxLength,
      maxLength = _props$maxLength === void 0 ? Infinity : _props$maxLength,
      _props$prefixCls = props.prefixCls,
      prefixCls = _props$prefixCls === void 0 ? defaultPrefixCls : _props$prefixCls,
      placeholder = props.placeholder,
      className = props.className,
      clear = props.clear,
      type = props.type,
      addonAfter = props.addonAfter,
      addonBefore = props.addonBefore,
      disabled = props.disabled,
      onHandleSelectionPos = props.onHandleSelectionPos,
      restProps = _objectWithoutProperties(props, ["defaultValue", "onChange", "maxLength", "prefixCls", "placeholder", "className", "clear", "type", "addonAfter", "addonBefore", "disabled", "onHandleSelectionPos"]);

  var _useState = useState(props.value || defaultValue || ''),
      _useState2 = _slicedToArray(_useState, 2),
      value = _useState2[0],
      setValue = _useState2[1];

  var inputRef = useRef(null);
  var selectionRef = useRef(null);
  useUpdateEffect(function () {
    if (props.value !== undefined && props.value !== value) {
      setValue(props.value || '');
    }
  }, [props.value, value]);

  var handlePosition = function handlePosition() {
    if (selectionRef.current) {
      try {
        inputRef.current.selectionStart = selectionRef.current.start || null;
        inputRef.current.selectionEnd = selectionRef.current.end || null;
      } catch (e) {}
    }
  };

  var focus = function focus() {
    inputRef.current.focus();
  };

  var blur = function blur() {
    inputRef.current.blur();
  };

  var select = function select() {
    inputRef.current.select();
  };

  useEffect(function () {
    handlePosition();
  }, [value]);
  useImperativeHandle(ref, function () {
    return {
      handlePosition: handlePosition,
      focus: focus,
      blur: blur,
      select: select
    };
  });

  var onRealChangeValue = function onRealChangeValue(v) {
    if (disabled) {
      return;
    }

    if (props.value === undefined) {
      setValue(v);
    }

    if (typeof onChange === 'function') {
      onChange(v);
    }
  };

  var onChangeValue = function onChangeValue(e) {
    var el = e.target;
    var elValue = el.value; // 如果当前值已经达到最大值,继续输入超过最大值的值,return掉

    if (value.length >= maxLength && elValue.length > maxLength) {
      return;
    }

    var currentValue = elValue;

    if (maxLength !== Infinity) {
      currentValue = currentValue.slice(0, maxLength);
    }

    try {
      var inputSelection = {};
      inputSelection.start = el.selectionStart;
      inputSelection.end = el.selectionEnd;

      if (inputSelection.start && inputSelection.start > maxLength + 1) {
        inputSelection.start = maxLength + 1;
      }

      if (inputSelection.end && inputSelection.end > maxLength + 1) {
        inputSelection.end = maxLength + 1;
      }

      if (typeof onHandleSelectionPos === 'function') {
        var _onHandleSelectionPos = onHandleSelectionPos(currentValue, inputSelection.start, inputSelection.end),
            start = _onHandleSelectionPos.start,
            end = _onHandleSelectionPos.end;

        if (isDef(start) && isDef(end)) {
          inputSelection.start = start;
          inputSelection.end = end;
        }
      }

      selectionRef.current = inputSelection;
    } catch (e) {}

    if (elValue.length > maxLength) {
      setTimeout(function () {
        handlePosition();
      });
    }

    if (currentValue !== value) {
      onRealChangeValue(currentValue);
    }
  };

  var onClearValue = function onClearValue() {
    onRealChangeValue('');
  };

  var needRenderClearIcon = clear && !disabled && value;
  var hasAddOnBefore = !!addonBefore;
  var hasAddOnAfter = needRenderClearIcon || !!addonAfter;
  var inputType = 'text';
  var patternProps;

  if (type === 'phone') {
    inputType = 'tel';
  } else if (type === 'digit') {
    inputType = 'number';
    patternProps = {
      pattern: '[0-9]*'
    };
  } else if (type) {
    inputType = type;
  }

  return /*#__PURE__*/React.createElement("div", {
    className: cn("".concat(prefixCls, "-input"), className)
  }, hasAddOnBefore && /*#__PURE__*/React.createElement("div", {
    className: cn("".concat(prefixCls, "-input-addons"))
  }, addonBefore), /*#__PURE__*/React.createElement("div", {
    className: cn("".concat(prefixCls, "-input-container"))
  }, /*#__PURE__*/React.createElement("input", _extends({}, patternProps, restProps, {
    ref: inputRef,
    value: value,
    type: inputType,
    onChange: onChangeValue,
    placeholder: placeholder,
    disabled: disabled,
    readOnly: disabled
  }))), hasAddOnAfter && /*#__PURE__*/React.createElement("div", {
    className: cn("".concat(prefixCls, "-input-addons"))
  }, needRenderClearIcon && /*#__PURE__*/React.createElement(CloseCircleFilled, {
    className: "".concat(prefixCls, "-input-icon"),
    onClick: onClearValue
  }), addonAfter));
}

;
export default /*#__PURE__*/forwardRef(InputItem);