import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _typeof from "@babel/runtime/helpers/typeof";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import ReactDOM from 'react-dom';
import LoadingOutlined from '@ant-design/icons/LoadingOutlined';
import CloseCircle from '../_icon/CloseCircle/index';
import CheckCircle from '../_icon/CheckCircle/index';
import PortalFactory from '../portal-factory/index';
import BaseToast from '../toast/toast';
import { defaultPrefixCls } from '../_config/dict';
var currentToast = null;
var timer = null;

var renderFn = function renderFn(props, _, destroy) {
  var originOnHide = props.onHide,
      restProps = _objectWithoutProperties(props, ["onHide"]);

  var onHideCb = function onHideCb() {
    typeof originOnHide === 'function' && originOnHide();
    destroy();
  };

  return /*#__PURE__*/React.createElement(BaseToast, _extends({}, restProps, {
    onHide: onHideCb
  }));
};

var destroyCurrentToast = function destroyCurrentToast() {
  if (timer) {
    clearTimeout(timer);
    timer = null;
  }

  if (currentToast) {
    currentToast.destroy();
  }
};

var drawToast = function drawToast(config) {
  destroyCurrentToast();
  var pf = PortalFactory(renderFn);
  currentToast = pf;
  pf.render(config);
};

var Toast = function Toast(props) {
  return /*#__PURE__*/ReactDOM.createPortal( /*#__PURE__*/React.createElement(BaseToast, props), document.body);
};

Toast.info = function (configOrContent) {
  var props = _typeof(configOrContent) === 'object' ? _objectSpread({}, configOrContent) : {};

  if (typeof configOrContent === 'string') {
    props.content = configOrContent;
  }

  drawToast(props);
};

Toast.loading = function (config) {
  var prefixCls = (config === null || config === void 0 ? void 0 : config.prefixCls) || defaultPrefixCls;

  var props = _objectSpread({
    icon: /*#__PURE__*/React.createElement(LoadingOutlined, {
      className: "".concat(prefixCls, "-toast-icon")
    }),
    duration: 0,
    content: '加载中...'
  }, config || {});

  drawToast(props);
};

Toast.delayLoading = function (delay, config) {
  var delayTime = delay || 500;
  timer = window.setTimeout(function () {
    Toast.loading(config);
    timer = null;
  }, delayTime);
};

Toast.fail = function (configOrContent) {
  var prefixCls = _typeof(configOrContent) === 'object' ? (configOrContent === null || configOrContent === void 0 ? void 0 : configOrContent.prefixCls) || defaultPrefixCls : defaultPrefixCls;
  var props = {
    icon: /*#__PURE__*/React.createElement(CloseCircle, {
      className: "".concat(prefixCls, "-toast-icon")
    })
  };

  if (_typeof(configOrContent) === 'object') {
    props = _objectSpread(_objectSpread({}, props), configOrContent);
  }

  if (typeof configOrContent === 'string') {
    props.content = configOrContent;
  }

  drawToast(props);
};

Toast.success = function (configOrContent) {
  var prefixCls = _typeof(configOrContent) === 'object' ? (configOrContent === null || configOrContent === void 0 ? void 0 : configOrContent.prefixCls) || defaultPrefixCls : defaultPrefixCls;
  var props = {
    icon: /*#__PURE__*/React.createElement(CheckCircle, {
      className: "".concat(prefixCls, "-toast-icon")
    })
  };

  if (_typeof(configOrContent) === 'object') {
    props = _objectSpread(_objectSpread({}, props), configOrContent);
  }

  if (typeof configOrContent === 'string') {
    props.content = configOrContent;
  }

  drawToast(props);
};

Toast.hide = function () {
  destroyCurrentToast();
};

export default Toast;