"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTimeObj = getTimeObj;
exports.parseFormatStr = parseFormatStr;
exports.getTimeStr = getTimeStr;
exports["default"] = void 0;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _react = require("react");

var _dayjs = _interopRequireDefault(require("dayjs"));

var _duration = _interopRequireDefault(require("dayjs/plugin/duration"));

var _index = require("../_util/index");

_dayjs["default"].extend(_duration["default"]);

var formatStringCache = {};
;
var limitUnit = ['s', 'm', 'H', 'D', 'M', 'Y'];
var limitUnitMap = {};
limitUnit.forEach(function (item, idx) {
  limitUnitMap[item] = idx;
});

function getTimeObj(duration, endTime, parseFormatString) {
  var timeObj = _dayjs["default"].duration(duration < 0 ? 0 : duration, 'seconds');

  if ((0, _index.isDef)(endTime) && (0, _index.isDef)(parseFormatString)) {
    var thisMoment = (0, _dayjs["default"])();
    var targetMoment = (0, _dayjs["default"])(endTime, parseFormatString);

    if (targetMoment.isAfter(thisMoment)) {
      timeObj = _dayjs["default"].duration(targetMoment.diff(thisMoment));
    }
  }

  return timeObj;
}

function parseFormatStr(formatString) {
  if (formatStringCache.hasOwnProperty(formatString)) {
    return formatStringCache[formatString];
  }

  var strArr = [];
  var piece = '';

  for (var i = 0; i < formatString.length;) {
    var c = formatString[i];

    if (limitUnitMap.hasOwnProperty(c)) {
      var j = i + 1;

      if (piece) {
        strArr.push(piece);
        piece = '';
      }

      while (j < formatString.length) {
        if (formatString[j] === c) {
          j++;
        } else {
          break;
        }
      }

      strArr.push(formatString.slice(i, j));
      i = j;
    } else {
      piece += c;
      i++;
    }
  }

  if (piece) {
    strArr.push(piece);
  }

  formatStringCache[formatString] = strArr;
  return strArr;
}

function getTimeStr(timeObj, formatString) {
  var strArr = parseFormatStr(formatString);
  var unitSet = new Set();

  for (var i = 0; i < strArr.length; i++) {
    var c = strArr[i][0];

    if (limitUnitMap.hasOwnProperty(c)) {
      unitSet.add(c);
    }
  }

  var unitArr = (0, _toConsumableArray2["default"])(unitSet).sort(function (a, b) {
    return limitUnitMap[b] - limitUnitMap[a];
  });
  var copyedTimeObj = timeObj.clone();
  var m = {};

  for (var _i = 0; _i < unitArr.length; _i++) {
    var mathFn = _i === unitArr.length - 1 ? Math.round : Math.floor;

    switch (unitArr[_i]) {
      case 'Y':
        m.Y = mathFn(copyedTimeObj.asYears());
        copyedTimeObj = copyedTimeObj.subtract(m.Y, 'years');
        break;

      case 'M':
        m.M = mathFn(copyedTimeObj.asMonths());
        copyedTimeObj = copyedTimeObj.subtract(m.M, 'months');
        break;

      case 'D':
        m.D = mathFn(copyedTimeObj.asDays());
        copyedTimeObj = copyedTimeObj.subtract(m.D, 'days');
        break;

      case 'H':
        m.H = mathFn(copyedTimeObj.asHours());
        copyedTimeObj = copyedTimeObj.subtract(m.H, 'hours');
        break;

      case 'm':
        m.m = mathFn(copyedTimeObj.asMinutes());
        copyedTimeObj = copyedTimeObj.subtract(m.m, 'minutes');
        break;

      case 's':
        m.s = mathFn(copyedTimeObj.asSeconds());
        copyedTimeObj = copyedTimeObj.subtract(m.s, 'seconds');
        break;
    }
  }

  return strArr.map(function (item) {
    var c = item[0];

    if (limitUnitMap.hasOwnProperty(c)) {
      return "".concat(m[c]).padStart(item.length, '0');
    }

    return item;
  }).join('');
}

var _default = function _default(props) {
  var _props$formatString = props.formatString,
      formatString = _props$formatString === void 0 ? 'mm:ss' : _props$formatString,
      _props$duration = props.duration,
      duration = _props$duration === void 0 ? 0 : _props$duration,
      endTime = props.endTime,
      _props$parseFormatStr = props.parseFormatString,
      parseFormatString = _props$parseFormatStr === void 0 ? 'YYYY-MM-DD HH:mm:ss' : _props$parseFormatStr,
      onFinished = props.onFinished,
      children = props.children;
  var timeObjRef = (0, _react.useRef)(getTimeObj(duration, endTime, parseFormatString));

  var _useState = (0, _react.useState)(getTimeStr(timeObjRef.current, formatString)),
      _useState2 = (0, _slicedToArray2["default"])(_useState, 2),
      timeStr = _useState2[0],
      setTimeStr = _useState2[1];

  (0, _react.useEffect)(function () {
    if (timeObjRef.current.asSeconds() < 1) {
      typeof onFinished === 'function' && onFinished();
    } else {
      var timer = setInterval(function () {
        if (timeObjRef.current.asSeconds() < 1) {
          clearInterval(timer);
          typeof onFinished === 'function' && onFinished();
        } else {
          timeObjRef.current = timeObjRef.current.subtract(1, 'seconds');
          setTimeStr(getTimeStr(timeObjRef.current, formatString));
        }
      }, 1000);
      return function () {
        clearInterval(timer);
      };
    }
  }, []);
  return typeof children === 'function' ? children(timeStr) : null;
};

exports["default"] = _default;