## SmsCodeBtn 手机短信验证码触发按钮

**0.0.2版本添加**

适用于与点击发送手机验证码相似的场景

#### 基本使用

```javascript
<SmsCodeBtn
  reText="重新获取"
  onClick={async (flowControlFn) => {
    const res = await api();
    if (res) {
      flowControlFn(true);
    } else {
      flowControlFn(false);
    }
  }}
/>
```

#### onClick 流程控制

当 `onClick` 回调触发, 组件内部将进入 loading 状态, 等待 onClick 函数中进行后续流程的控制

0.0.5 版本之前

`onClick` 接收一个开始倒计时的函数 `beginCountDownFn(): void`, 可以使用这个函数结束 loading 状态并进入倒计时

0.0.5 版本

`onClick` 接收流程控制函数 `flowControlFn(isContinue?: boolean): void`, 这个流程控制函数接收是否继续的参数.

为了向下兼容, 你可以不传递 isContinue, 此时认为继续流程.

```javascript
// 继续流程 loading 态 -> 开始倒计时
flowControlFn(true);
// 等同于 flowControlFn(true);
flowControlFn();
// 终止流程 取消 loading 态
flowControlFn(false);
```

#### 强制结束倒计时(0.0.5 版本新增)

你可以传递一个 ref, 获得 `SmsCodeBtn` 组件的 `ref` 接口能力

```javascript
const ref = React.createRef();
<SmsCodeBtn
  ref={ref}
/>
// ...
ref.current.cancelCountDown();
```

#### API

| 成员 | 说明 | 类型 | 默认值 | 版本 |
| --- | --- | --- | --- | --- |
| prefixCls | class 前缀 | string | - | 0.0.2 |
| className | class | string | - | 0.0.2 |
| disabled | 是否被禁用 | boolean | - | 0.0.2 |
| duration | 倒计时的时间 | number | 60 | 0.0.2 |
| text | 默认展示的文案 | ReactNode | '获取验证码' | 0.0.2 |
| reText | 触发一次点击并倒计时后第二次开始时展示的文案 | ReactNode | '获取验证码' | 0.0.2 |
| renderCountDown | 根据倒计时渲染自定义文案 | (timeStr: string) => React.ReactNode | - | 0.0.2 |
| onClick | 点击组件时触发 | (beginCountDownFn: () => void) => void | - | 0.0.2 |
| onClick | 点击组件时触发 | (flowControlFn: (isContinue?: boolean) => void) => void | - | 0.0.5 |
| onClickDisabled | 当disabled为true时点击组件时触发，你可以在这个钩子中进行Toast提示 | () => void | - | 0.0.2 |
| initDispatch | 是否初始状态就触发一次 onClick 事件(无需点击，适用于第一次直接发送验证码的场景) | boolean | - | 0.0.4 |


#### Ref 接口

+ `cancelCountDown(): void` (0.0.5版本起支持)

结束当前正在进行的倒计时